Structs
- Struct that benefits to define a foreign key.
- Struct that benefits you to add a foreign key item to a foreign key.
- Struct that benefits to build queries for interactions with rdbms’s.
- Struct that benefits you to create and use schema’s.
- Struct that benefits you to create Tables. Currently incomplete thoug.
Enums
- Enum that benefits you to define what you want with a foreign key.
- KeywordList enum. It helps to syntactically correcting the queries.
- QueryType enum. It helps to detect the type of a query with more optimized way when is needed.
- ValueType enum. It benefits to detect and format the value with optimized way when you have to work with exact column values.